#!/bin/sh
#
# spamass-milter Starts and stops the spamass-milter daemon
#
# chkconfig:	- 81 19
# description:	spamass-milter is a daemon which hooks into sendmail and routes
#		email messages to spamassassin
# processname:	spamass-milter
# config:	/etc/sysconfig/spamass-milter
# pidfile:	/var/run/spamass.pid


# Source function library.
. /etc/rc.d/init.d/functions

# Source networking configuration.
. /etc/sysconfig/network

# Local spamass-milter config
. /etc/sysconfig/spamass-milter

# Check that networking is up.
[ ${NETWORKING} = "no" ] && exit 0

[ -x /usr/sbin/spamass-milter ] || exit 0
PATH=$PATH:/usr/sbin

RETVAL=0

start() {
        echo -n $"Starting spamass-milter:"
        daemon spamass-milter -f $SM_FLAGS -- $SM_EXTRA_FLAGS
        RETVAL=$?
        echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/spamass-milter
	return $RETVAL
}

stop() {
        echo -n $"Shutting down spamass-milter:"
        killproc spamass-milter
        RETVAL=$?
        echo
	[ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/spamass-milter
	return $RETVAL
}

# See how we were called.
case "$1" in
  start)
	start
	RETVAL=$?
        ;;
  stop)
	stop
	RETVAL=$?
        ;;
  restart)
	stop
	start
	RETVAL=$?
        ;;
  condrestart)
	test -f /var/lock/subsys/spamass-milter && $0 restart || :
	RETVAL=$?
        ;;
  reload)
	killproc spamass-milter -HUP
	RETVAL=$?
	;;
  status)
        status spamass-milter
	RETVAL=$?
        ;;
  *)
        echo $"Usage: $0 {start|stop|reload|restart|condrestart|status}"
        exit 1
esac

exit $RETVAL

